@@ -96,9 +96,7 @@ def setup_test_account():
             cli_token=cli_token,
         )
     )
-    access_token = vessl.vessl_api.sign_in_cli_check_api(
-        cli_token=cli_token
-    ).access_token
+    access_token = vessl.vessl_api.sign_in_cli_check_api(cli_token=cli_token).access_token
     vessl.configure_access_token(access_token=access_token)
 
     # Configure organization
