@@ -25,11 +25,11 @@ class TestDataset:
 
     @pytest.mark.order(index=2)
     def test_upload_dataset_volume_file(self):
+        vessl.upload_dataset_volume_file(self.dataset_name, "test/fixture/file1.txt", "file1.txt")
         vessl.upload_dataset_volume_file(
-            self.dataset_name, "test/fixture/file1.txt", "file1.txt"
-        )
-        vessl.upload_dataset_volume_file(
-            self.dataset_name, "test/fixture/folder1", "folder1",
+            self.dataset_name,
+            "test/fixture/folder1",
+            "folder1",
         )
 
     def test_read_dataset(self):
@@ -46,13 +46,17 @@ class TestDataset:
             self.dataset_name, "file1.txt", "test/fixture/tmp/file2.txt"
         )
         vessl.download_dataset_volume_file(
-            self.dataset_name, "folder1", "test/fixture/tmp/folder1",
+            self.dataset_name,
+            "folder1",
+            "test/fixture/tmp/folder1",
         )
 
     def test_copy_dataset_volume_file(self):
         vessl.copy_dataset_volume_file(self.dataset_name, "file1.txt", "file1_copy.txt")
         vessl.copy_dataset_volume_file(
-            self.dataset_name, "folder1", "folder1_copy",
+            self.dataset_name,
+            "folder1",
+            "folder1_copy",
         )
 
     @pytest.mark.order(index=-1)
