@@ -1,4 +1,4 @@
-from test.conftest import USE_MOCK
+from test.conftest import TEST_CLUSTER_NAME, USE_MOCK
 
 import pytest
 
@@ -8,7 +8,7 @@ import vessl
 @pytest.mark.skipif(USE_MOCK, reason="Does not run if mocking is used.")
 class TestKernelCluster:
     def test_read_cluster(self):
-        vessl.read_cluster("aws-uw2-dev")  # TODO: change when CI server is relocated
+        vessl.read_cluster(TEST_CLUSTER_NAME)
 
     def test_list_clusters(self):
         vessl.list_clusters()
