@@ -1,8 +1,9 @@
+from test.conftest import USE_MOCK
+
 import pytest
 from mock import Mock, patch
 
 import vessl
-from test.conftest import USE_MOCK
 from vessl.util.exception import InvalidProjectError
 from vessl.util.random import random_string
 
@@ -46,9 +47,7 @@ def test_get_project():
     project = Mock()
     project.name = project_name
     with patch.object(vessl.project, "read_project", return_value=project):
-        assert (
-            vessl.project._get_project(project_name=project_name).name == project_name
-        )
+        assert vessl.project._get_project(project_name=project_name).name == project_name
 
     with patch.object(vessl.vessl_api, "project", project):
         assert vessl.project._get_project().name == project_name
