@@ -88,12 +88,14 @@ from vessl.organization import (
     list_organizations,
     read_organization,
 )
-from vessl.project import create_project, list_projects, read_project
-from vessl.service import (
-    RunnerBase,
-    register_model,
-    register_torch_model,
+from vessl.pipeline import (
+    update_context_variables,
+    get_context_variable,
+    get_argument_value,
+    read_pipeline,
 )
+from vessl.project import create_project, list_projects, read_project
+from vessl.service import RunnerBase, register_model, register_torch_model
 from vessl.ssh_key import create_ssh_key, delete_ssh_key, list_ssh_keys
 from vessl.sweep import (
     create_sweep,
