@@ -2,9 +2,7 @@ import os
 import sys
 from typing import List
 
-project_root = os.path.dirname(
-    os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-)
+project_root = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 # this line should be on the top to run it on a local environment as 'python vessl/cli/_main.py'
 sys.path.append(project_root)
 
@@ -118,7 +116,8 @@ def configure(
 
     try:
         vessl.configure_organization(
-            organization_name=organization, credentials_file=credentials_file,
+            organization_name=organization,
+            credentials_file=credentials_file,
         )
     except InvalidOrganizationError:
         organization_name = prompt_organizations()
@@ -126,7 +125,8 @@ def configure(
 
     try:
         vessl.configure_project(
-            project_name=project, credentials_file=credentials_file,
+            project_name=project,
+            credentials_file=credentials_file,
         )
     except InvalidProjectError:
         projects = vessl.list_projects()
@@ -164,12 +164,14 @@ def whoami():
         print("Please run `vessl configure` first.")
         return
 
-    print(f"""Username: {user.username}
+    print(
+        f"""Username: {user.username}
 Email: {user.email}
 Default organization: {organization_name}
 Default project: {project_name or 'N/A'}
 
-(The default organization and project can be updated with `vessl configure --reset`.)""")
+(The default organization and project can be updated with `vessl configure --reset`.)"""
+    )
 
 
 @configure.vessl_command()
