@@ -63,9 +63,7 @@ def cli():
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=dataset_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
 @organization_name_option
 def read(name: str):
     dataset = read_dataset(dataset_name=name)
@@ -79,9 +77,7 @@ def read(name: str):
             "Source": dataset.source.provider,
         }
     )
-    print(
-        f"For more info: {Endpoint.dataset.format(dataset.organization.name, dataset.name)}"
-    )
+    print(f"For more info: {Endpoint.dataset.format(dataset.organization.name, dataset.name)}")
 
 
 @cli.vessl_command()
@@ -96,9 +92,7 @@ def list():
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=generic_prompter("Dataset name")
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=generic_prompter("Dataset name"))
 @click.option("-m", "--description", type=click.STRING)
 @click.option(
     "--is-public",
@@ -145,9 +139,7 @@ def create(
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=dataset_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
 @click.option("-p", "--path", type=click.Path(), default="", help="Defaults to root.")
 @click.option("-r", "--recursive", is_flag=True)
 @organization_name_option
@@ -166,9 +158,7 @@ def list_files(
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=dataset_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
 @vessl_argument(
     "source",
     type=click.Path(exists=True),
@@ -204,9 +194,7 @@ def upload(name: str, source: str, dest: str):
     required=True,
     prompter=generic_prompter("Source path", default="/"),
 )
-@vessl_argument(
-    "dest", type=click.Path(), required=True, prompter=download_dest_path_prompter
-)
+@vessl_argument("dest", type=click.Path(), required=True, prompter=download_dest_path_prompter)
 @organization_name_option
 def download(name: str, source: str, dest: str):
     download_dataset_volume_file(
@@ -217,9 +205,7 @@ def download(name: str, source: str, dest: str):
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=dataset_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
 @vessl_argument(
     "source", type=click.Path(), required=True, prompter=generic_prompter("Source path")
 )
@@ -240,12 +226,8 @@ def copy(name: str, source: str, dest: str):
 
 
 @cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=dataset_name_prompter
-)
-@vessl_argument(
-    "path", type=click.Path(), required=True, prompter=generic_prompter("File path")
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
+@vessl_argument("path", type=click.Path(), required=True, prompter=generic_prompter("File path"))
 @organization_name_option
 def delete_file(name: str, path: str):
     delete_dataset_volume_file(
