@@ -53,9 +53,7 @@ def experiment_number_prompter(
     value: str,
 ) -> str:
     experiments = list_experiments()
-    return prompt_choices(
-        "Experiment", [(f"#{x.number}", x.number) for x in reversed(experiments)]
-    )
+    return prompt_choices("Experiment", [(f"#{x.number}", x.number) for x in reversed(experiments)])
 
 
 def local_experiment_number_prompter(
@@ -64,14 +62,10 @@ def local_experiment_number_prompter(
     value: str,
 ) -> str:
     experiments = [e for e in list_experiments() if e.is_local]
-    return prompt_choices(
-        "Experiment", [(f"#{x.number}", x.number) for x in reversed(experiments)]
-    )
+    return prompt_choices("Experiment", [(f"#{x.number}", x.number) for x in reversed(experiments)])
 
 
-def processor_type_prompter(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def processor_type_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
     cluster = ctx.obj.get("cluster")
     if cluster is None:
         raise click.BadOptionUsage(
@@ -91,9 +85,7 @@ def processor_type_callback(ctx: click.Context, param: click.Parameter, value: s
     return value
 
 
-def cpu_limit_prompter(
-    ctx: click.Context, param: click.Parameter, value: float
-) -> float:
+def cpu_limit_prompter(ctx: click.Context, param: click.Parameter, value: float) -> float:
     cluster = ctx.obj.get("cluster")
     if cluster is None:
         raise click.BadOptionUsage(
@@ -105,9 +97,7 @@ def cpu_limit_prompter(
         return click.prompt("CPUs (in vCPU)", type=click.FLOAT)
 
 
-def memory_limit_prompter(
-    ctx: click.Context, param: click.Parameter, value: float
-) -> float:
+def memory_limit_prompter(ctx: click.Context, param: click.Parameter, value: float) -> float:
     cluster = ctx.obj.get("cluster")
     if cluster is None:
         raise click.BadOptionUsage(
@@ -138,9 +128,7 @@ def gpu_type_prompter(ctx: click.Context, param: click.Parameter, value: str) ->
             return prompt_choices("GPU Type", [x.gpu_product_name for x in nodes])
 
 
-def gpu_limit_prompter(
-    ctx: click.Context, param: click.Parameter, value: float
-) -> float:
+def gpu_limit_prompter(ctx: click.Context, param: click.Parameter, value: float) -> float:
     cluster = ctx.obj.get("cluster")
     if cluster is None:
         raise click.BadOptionUsage(
@@ -169,7 +157,19 @@ def image_url_prompter(ctx: click.Context, param: click.Parameter, value: str) -
     images = list_kernel_images()
     images = [x for x in images if x.processor_type == processor_type]
 
-    return prompt_choices("Image URL", [x.image_url for x in images])
+    # Pretty print image name+URL choices
+    name_maxlen = len(max(images, key=lambda x: len(x.name)).name)
+
+    return prompt_choices(
+        "Image",
+        [
+            (
+                f"{x.name}" + " " * (name_maxlen - len(x.name) + 2) + f"(URL: {x.image_url})",
+                x.image_url,
+            )
+            for x in images
+        ],
+    )
 
 
 def upload_local_file_callback(
@@ -213,9 +213,7 @@ def upload_local_file_callback(
     return value
 
 
-def worker_count_callback(
-    ctx: click.Context, param: click.Parameter, value: int
-) -> int:
+def worker_count_callback(ctx: click.Context, param: click.Parameter, value: int) -> int:
     if value is None:
         value = 1
 
@@ -229,9 +227,7 @@ def worker_count_callback(
     return value
 
 
-def framework_type_prompter(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def framework_type_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
     worker_count = ctx.obj.get("worker_count")
     if worker_count == 1:
         return ""
@@ -252,7 +248,10 @@ def cli():
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @organization_name_option
 @project_name_option
@@ -463,6 +462,12 @@ framework_type_option = vessl_option(
 @organization_name_option
 @project_name_option
 @cluster_option
+@vessl_option(
+    "--node",
+    type=click.STRING,
+    multiple=True,
+    help="Cluster nodes. Defaults to all nodes in cluster.",
+)
 @resource_option
 @processor_type_option
 @cpu_limit_option
@@ -489,6 +494,7 @@ framework_type_option = vessl_option(
 def create(
     ctx,
     cluster: str,
+    node: List[str],
     command: str,
     resource: str,
     processor_type: str,
@@ -515,6 +521,7 @@ def create(
 ):
     experiment = create_experiment(
         cluster_name=cluster,
+        cluster_node_names=node,
         start_command=command,
         kernel_resource_spec_name=resource,
         processor_type=processor_type,
@@ -556,7 +563,10 @@ worker_number_option = vessl_option(
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @click.option(
     "--tail",
@@ -580,9 +590,7 @@ def logs(
     worker_number: int,
 ):
     if not follow:
-        logs = list_experiment_logs(
-            experiment_number=number, tail=tail, worker_numer=worker_number
-        )
+        logs = list_experiment_logs(experiment_number=number, tail=tail, worker_numer=worker_number)
         print_logs(logs)
         print(f"Displayed last {len(logs)} lines of #{number}.")
         return
@@ -597,10 +605,7 @@ def logs(
         ):
             experiment_finished_dt = time.time()
 
-        if (
-            experiment_finished_dt is not None
-            and (time.time() - experiment_finished_dt) > 5
-        ):
+        if experiment_finished_dt is not None and (time.time() - experiment_finished_dt) > 5:
             break
 
         logs = list_experiment_logs(
@@ -618,7 +623,10 @@ def logs(
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @organization_name_option
 @project_name_option
@@ -638,7 +646,10 @@ def list_output(
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @click.option(
     "-p",
@@ -665,7 +676,10 @@ def download_output(
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @organization_name_option
 @project_name_option
@@ -697,7 +711,10 @@ def download_code():
 
 @cli.vessl_command()
 @vessl_argument(
-    "number", type=click.INT, required=True, prompter=experiment_number_prompter,
+    "number",
+    type=click.INT,
+    required=True,
+    prompter=experiment_number_prompter,
 )
 @organization_name_option
 @project_name_option
