@@ -11,9 +11,7 @@ from vessl.kernel_resource_spec import (
 )
 
 
-def resource_name_prompter(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def resource_name_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
     cluster = ctx.obj.get("cluster")
     if cluster is None:
         raise click.BadOptionUsage(
@@ -36,9 +34,7 @@ def resource_name_prompter(
         return resource.name
 
 
-def resource_name_callback(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def resource_name_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
     if "cluster" not in ctx.obj:
         raise click.BadOptionUsage(
             option_name="--cluster",
@@ -64,14 +60,10 @@ def cli():
     required=True,
     prompter=cluster_id_prompter,
 )
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=resource_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=resource_name_prompter)
 @organization_name_option
 def read(cluster: int, name: str):
-    resource = read_kernel_resource_spec(
-        cluster_id=cluster, kernel_resource_spec_name=name
-    )
+    resource = read_kernel_resource_spec(cluster_id=cluster, kernel_resource_spec_name=name)
     print_data(
         {
             "ID": resource.id,
