@@ -52,9 +52,7 @@ def model_repository_update_dt(
     return truncate_datetime(default)
 
 
-def model_repository_name_callback(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def model_repository_name_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
     if value:
         ctx.obj["repository"] = value
     return value
@@ -70,9 +68,7 @@ def model_repository_name_prompter(
         raise click.UsageError(
             message="Create model repository with `vessl model-repository create`"
         )
-    repository = prompt_choices(
-        "Model repository", [x.name for x in model_repositories]
-    )
+    repository = prompt_choices("Model repository", [x.name for x in model_repositories])
     ctx.obj["repository"] = repository
     return repository
 
@@ -83,9 +79,7 @@ def model_repository_cli():
 
 
 @model_repository_cli.vessl_command()
-@vessl_argument(
-    "name", type=click.STRING, required=True, prompter=model_repository_name_prompter
-)
+@vessl_argument("name", type=click.STRING, required=True, prompter=model_repository_name_prompter)
 @organization_name_option
 def read(name: str):
     model_repository = read_model_repository(repository_name=name)
@@ -94,9 +88,7 @@ def read(name: str):
             "ID": model_repository.id,
             "Name": model_repository.name,
             "Description": model_repository.description,
-            "Status": model_repository_status(
-                model_repository.model_summary.latest_model
-            ),
+            "Status": model_repository_status(model_repository.model_summary.latest_model),
             "Organization": model_repository.organization.name,
             "Created": truncate_datetime(model_repository.created_dt),
             "Updated": truncate_datetime(model_repository.updated_dt),
@@ -518,9 +510,7 @@ def download(repository_name: str, model_number: int, source: str, dest: str):
     required=True,
     prompter=model_number_prompter,
 )
-@vessl_argument(
-    "path", type=click.Path(), required=True, prompter=generic_prompter("File path")
-)
+@vessl_argument("path", type=click.Path(), required=True, prompter=generic_prompter("File path"))
 @organization_name_option
 def delete_file(repository_name: str, model_number: int, path: str):
     delete_model_volume_file(
