@@ -19,9 +19,7 @@ from vessl.organization import (
 from vessl.util.exception import InvalidOrganizationError
 
 
-def organization_name_prompter(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def organization_name_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
     organizations = list_organizations()
     return prompt_choices("Organization", [x.name for x in organizations])
 
@@ -73,16 +71,12 @@ def create(name: str):
     )
 
 
-def organization_name_callback(
-    ctx: click.Context, param: click.Parameter, value: str
-) -> str:
+def organization_name_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
     try:
         organization_name = vessl.vessl_api.set_organization(value)
         print(f"Organization: {organization_name}")
     except InvalidOrganizationError:
-        print(
-            "Invalid organization. Please choose an organization using `vessl configure`."
-        )
+        print("Invalid organization. Please choose an organization using `vessl configure`.")
         sys.exit(1)
 
 
