@@ -51,8 +51,8 @@ def list():
     projects = list_projects()
     print_table(
         projects,
-        ["ID", "Name", "Experiments"],
-        lambda x: [x.id, x.name, x.experiment_summary.total],
+        ["Name", "Experiments"],
+        lambda x: [x.name, x.experiment_summary.total],
     )
 
 
