@@ -25,9 +25,7 @@ def ssh_key_id_callback(ctx: click.Context, param: click.Parameter, value: id) -
     )
 
 
-def ssh_public_key_value_callback(
-    ctx: click.Context, param: click.Option, key_path: str
-) -> str:
+def ssh_public_key_value_callback(ctx: click.Context, param: click.Option, key_path: str) -> str:
     if not key_path:
         key_path = inquirer.prompt(
             [
