@@ -195,9 +195,8 @@ def list():
     sweeps = list_sweeps()
     print_table(
         sweeps,
-        ["ID", "Name", "Status", "Created", "Experiments"],
+        ["Name", "Status", "Created", "Experiments"],
         lambda x: [
-            x.id,
             x.name,
             x.status,
             truncate_datetime(x.created_dt),
@@ -212,41 +211,35 @@ def list():
     "-T",
     "--objective-type",
     type=click.Choice(SWEEP_OBJECTIVE_TYPES),
-    required=True,
     prompter=choices_prompter("Objective type", SWEEP_OBJECTIVE_TYPES),
 )
 @vessl_option(
     "-M",
     "--objective-metric",
     type=click.STRING,
-    required=True,
     prompter=generic_prompter("Objective metric", click.STRING),
 )
 @vessl_option(
     "-G",
     "--objective-goal",
     type=click.STRING,
-    required=True,
     prompter=generic_prompter("Objective goal", click.FLOAT),
 )
 @vessl_option(
     "--num-experiments",
     type=click.INT,
-    required=True,
     prompter=generic_prompter("Maximum number of experiments", click.INT),
     help="Maximum number of experiments.",
 )
 @vessl_option(
     "--num-parallel",
     type=click.INT,
-    required=True,
     prompter=generic_prompter("Number of experiments to be run in parallel", click.INT),
     help="Number of experiments to be run in parallel.",
 )
 @vessl_option(
     "--num-failed",
     type=click.INT,
-    required=True,
     prompter=generic_prompter("Maximum number of experiments to allow to fail", click.INT),
     help="Maximum number of experiments to allow to fail.",
 )
@@ -308,7 +301,7 @@ def create(
     resource: str,
     processor_type: str,
     cpu_limit: float,
-    memory_limit: float,
+    memory_limit: str,
     gpu_type: str,
     gpu_limit: int,
     image_url: str,
@@ -324,13 +317,16 @@ def create(
     working_dir: str,
     output_dir: str,
 ):
-    sweep = create_sweep(
-        name=name,
-        objective=OrmSweepObjective(
+    objective = None
+    if objective_type is not None:
+        objective = OrmSweepObjective(
             type=objective_type,
             goal=objective_goal,
             metric=objective_metric,
-        ),
+        )
+    sweep = create_sweep(
+        name=name,
+        objective=objective,
         max_experiment_count=num_experiments,
         parallel_experiment_count=num_parallel,
         max_failed_experiment_count=num_failed,
@@ -340,14 +336,14 @@ def create(
             for p in parameter
         ],
         cluster_name=cluster,
-        start_command=command,
-        kernel_resource_spec_name=resource,
+        command=command,
+        resource_spec_name=resource,
         processor_type=processor_type,
         cpu_limit=cpu_limit,
         memory_limit=memory_limit,
         gpu_type=gpu_type,
         gpu_limit=gpu_limit,
-        kernel_image_url=image_url,
+        image_url=image_url,
         early_stopping_name=early_stopping_name,
         early_stopping_settings=early_stopping_settings,
         message=message,
