@@ -72,7 +72,10 @@ def delete(id: int, path: str):
     prompter=generic_prompter("Destination path"),
 )
 def copy(
-    source_id: int, source_path: str, dest_id: int, dest_path: str,
+    source_id: int,
+    source_path: str,
+    dest_id: int,
+    dest_path: str,
 ):
     copy_volume_file(
         source_volume_id=source_id,
