@@ -13,7 +13,12 @@ from vessl import vessl_api
 from vessl.organization import _get_organization_name
 from vessl.util.constant import DATASET_PATH_SCHEME_GS, DATASET_PATH_SCHEME_S3
 from vessl.util.exception import InvalidDatasetError
-from vessl.volume import copy_volume_file, delete_volume_file, list_volume_files, _copy_volume_file_remote_to_local
+from vessl.volume import (
+    _copy_volume_file_remote_to_local,
+    copy_volume_file,
+    delete_volume_file,
+    list_volume_files,
+)
 
 
 def read_dataset(dataset_name: str, **kwargs) -> ResponseDatasetInfoDetail:
@@ -182,9 +187,7 @@ def create_dataset(
         ```
     """
     if external_path is None:
-        return _create_dataset_local(
-            dataset_name, is_version_enabled, description, **kwargs
-        )
+        return _create_dataset_local(dataset_name, is_version_enabled, description, **kwargs)
 
     if external_path.startswith(DATASET_PATH_SCHEME_S3):
         return _create_dataset_s3(
