@@ -44,9 +44,7 @@ class HyperparametersController(object):
             )
 
         except (MaxRetryError, VesslApiException) as e:
-            logger.exception(
-                "Failed to update hyperparameters to experiment", exc_info=e
-            )
+            logger.exception("Failed to update hyperparameters to experiment", exc_info=e)
 
         except Exception as e:
             logger.exception("Unexpected error", exc_info=e)
