@@ -171,9 +171,7 @@ class VesslRun(object):
         if experiment_number is None:
             from vessl.experiment import create_local_experiment
 
-            experiment = create_local_experiment(
-                message=message, hyperparameters=hyperparameters
-            )
+            experiment = create_local_experiment(message=message, hyperparameters=hyperparameters)
             logger.debug(f"Created experiment {experiment.id}")
             return experiment
 
@@ -186,9 +184,7 @@ class VesslRun(object):
                 f"{experiment.number}: cannot use Vessl-managed experiment."
             )
         if experiment.status != "running":
-            raise InvalidExperimentError(
-                f"{experiment.number}: experiment must be running."
-            )
+            raise InvalidExperimentError(f"{experiment.number}: experiment must be running.")
 
         return experiment
 
@@ -227,9 +223,7 @@ class VesslRun(object):
         assert self._mode == MODE_MANAGED
         res = self.api.experiment_metrics_update_api(
             self._experiment.id,
-            experiment_metrics_update_api_input=ExperimentMetricsUpdateAPIInput(
-                metrics=payloads
-            ),
+            experiment_metrics_update_api_input=ExperimentMetricsUpdateAPIInput(metrics=payloads),
         )
         if res.rejected:
             logger.warning(f"{res.rejected} payloads(s) were rejected.")
@@ -367,14 +361,20 @@ class VesslRun(object):
 
         for k, v in payload.items():
             if isinstance(v, list):
-                if all(isinstance(i, Image) for i in v) or all(
-                    isinstance(i, Audio) for i in v
-                ):
+                if all(isinstance(i, Image) for i in v) or all(isinstance(i, Audio) for i in v):
                     media_dict[k] = v
             elif isinstance(v, Image) or isinstance(v, Audio):
                 media_dict[k] = [v]
-            else:
+            elif isinstance(v, int) or isinstance(v, float):
                 scalar_dict[k] = v
+            else:
+                try:
+                    scalar_dict[k] = float(v)
+                except ValueError:
+                    logger.error(
+                        f"Could not convert '{type(v).__name__}' {v} to float. "
+                        f"(allowed types: Image, Audio, int, float)"
+                    )
 
         # Update step if step is specified. If a scalar is defined but step wasn't,
         # step will be autoincremented.
@@ -424,9 +424,7 @@ class VesslRun(object):
                 path_to_caption[path] = medium.caption
                 if not set_media_type:
                     if not isinstance(medium, Image) and not isinstance(medium, Audio):
-                        raise InvalidTypeError(
-                            f"Invalid payload type error: {type(medium)}"
-                        )
+                        raise InvalidTypeError(f"Invalid payload type error: {type(medium)}")
                     else:
                         media_type = type(medium).__name__
                         set_media_type = True
@@ -464,9 +462,7 @@ class VesslRun(object):
                 payload = {VESSL_PLOTS_FILETYPE_IMAGE: f}
             elif media_type == Audio.__name__:
                 payload = {VESSL_PLOTS_FILETYPE_AUDIO: f}
-            payloads.append(
-                self._user_metric_collector.build_media_payload(payload, ts)
-            )
+            payloads.append(self._user_metric_collector.build_media_payload(payload, ts))
 
         if self._mode == MODE_MANAGED:
             self._send_without_collector(payloads)
