@@ -77,9 +77,7 @@ class RunnerBase(abc.ABC):
         pass
 
     @staticmethod
-    def load_model(
-        props: Union[Dict[str, str], None], artifacts: Dict[str, str]
-    ) -> ModelType:
+    def load_model(props: Union[Dict[str, str], None], artifacts: Dict[str, str]) -> ModelType:
         """Load the model instance from file.
 
         `props` is given from the return value of `save_model`, and `artifacts` is
@@ -179,9 +177,7 @@ def _save_object(save_type: Union[str, None], obj: Any, path: str) -> str:
         import torch
 
         with open(path, "wb") as f:
-            torch.save(
-                obj, f, pickle_module=cloudpickle, pickle_protocol=PROTOCOL_VERSION
-            )
+            torch.save(obj, f, pickle_module=cloudpickle, pickle_protocol=PROTOCOL_VERSION)
         return "torch"
     if save_type is not None:
         # save_type given, but we don't know how to handle it
@@ -280,22 +276,12 @@ def _upload_artifacts(
     """
     # Input Validation
     for local_path, remote_path in artifacts.items():
-        local_dir, local_base = os.path.dirname(local_path), os.path.basename(
-            local_path
-        )
-        remote_dir, remote_base = os.path.dirname(remote_path), os.path.basename(
-            remote_path
-        )
+        local_dir, local_base = os.path.dirname(local_path), os.path.basename(local_path)
+        remote_dir, remote_base = os.path.dirname(remote_path), os.path.basename(remote_path)
         if "*" in local_dir or "*" in remote_dir:
-            raise InvalidParamsError(
-                "Only trailing asterisk(*) is allowed for glob pattern"
-            )
-        if ("*" in local_base and local_base != "*") or (
-            "*" in remote_base and remote_base != "*"
-        ):
-            raise InvalidParamsError(
-                "Only trailing asterisk(*) is allowed for glob pattern"
-            )
+            raise InvalidParamsError("Only trailing asterisk(*) is allowed for glob pattern")
+        if ("*" in local_base and local_base != "*") or ("*" in remote_base and remote_base != "*"):
+            raise InvalidParamsError("Only trailing asterisk(*) is allowed for glob pattern")
         if (local_base == "*") != (remote_base == "*"):
             # Both should either or neither be glob pattern
             raise InvalidParamsError(
@@ -308,12 +294,8 @@ def _upload_artifacts(
             print("  {} -> {}".format(l, r))
 
     for local_path, remote_path in artifacts.items():
-        local_dir, local_base = os.path.dirname(local_path), os.path.basename(
-            local_path
-        )
-        remote_dir, remote_base = os.path.dirname(remote_path), os.path.basename(
-            remote_path
-        )
+        local_dir, local_base = os.path.dirname(local_path), os.path.basename(local_path)
+        remote_dir, remote_base = os.path.dirname(remote_path), os.path.basename(remote_path)
         if local_base == "*":
             # Glob pattern
             for root, _, files in os.walk(local_dir):
@@ -358,9 +340,7 @@ def _register_serving_method(
     if model_number is None and model_instance is None:  # Exclude (0, x, 0)
         raise InvalidParamsError("`model_instance` must be given to create a new model")
     if model_instance is None and model_type is not None:  # Exclude (x, 1, 0)
-        raise InvalidParamsError(
-            "`model_instance` must be given if `model_type` is not None"
-        )
+        raise InvalidParamsError("`model_instance` must be given if `model_type` is not None")
     for key in artifacts:
         if key in [RUNNER_FILENAME, MANIFEST_FILENAME, DEFAULT_MODEL_FILENAME]:
             raise InvalidParamsError("`{}` is a reserved key of artifacts".format(key))
@@ -416,9 +396,7 @@ def _register_serving_method(
             model_save_type = USER_DEFINED
         else:
             # Use the default saver
-            model_save_type = _save_object(
-                model_type, model_instance, DEFAULT_MODEL_FILENAME
-            )
+            model_save_type = _save_object(model_type, model_instance, DEFAULT_MODEL_FILENAME)
             model_save_path = DEFAULT_MODEL_FILENAME
 
     # Save the runner
@@ -625,9 +603,7 @@ def _load_model(install_reqs: bool = False) -> _ModelServer:
         try:
             manifest = yaml.load(f, Loader=yaml.FullLoader)
         except yaml.YAMLError:
-            raise VesslRuntimeException(
-                "Invalid manifest file. Please register the model again."
-            )
+            raise VesslRuntimeException("Invalid manifest file. Please register the model again.")
 
     _manifest_schema.validate(manifest)
     # Check for requirements
@@ -638,18 +614,12 @@ def _load_model(install_reqs: bool = False) -> _ModelServer:
             subprocess.check_call(["pip", "install", *reqs])  # Support for conda?
 
     # Load runner
-    runner_cls = _load_object(
-        manifest["runner"]["save_type"], manifest["runner"]["save_path"]
-    )
+    runner_cls = _load_object(manifest["runner"]["save_type"], manifest["runner"]["save_path"])
     # Load model
     if "load_model" in manifest["use_default"]:
-        model = _load_object(
-            manifest["model"]["save_type"], manifest["model"]["save_path"]
-        )
+        model = _load_object(manifest["model"]["save_type"], manifest["model"]["save_path"])
     else:  # Use custom loader
-        model = runner_cls.load_model(
-            manifest["model"]["save_output"], manifest["artifacts"]
-        )
+        model = runner_cls.load_model(manifest["model"]["save_output"], manifest["artifacts"])
     # Load methods
     preprocess_data = (
         (lambda x: x)
@@ -661,9 +631,7 @@ def _load_model(install_reqs: bool = False) -> _ModelServer:
         if "postprocess_data" in manifest["use_default"]
         else runner_cls.postprocess_data
     )
-    model_server = _ModelServer(
-        model, preprocess_data, runner_cls.predict, postprocess_data
-    )
+    model_server = _ModelServer(model, preprocess_data, runner_cls.predict, postprocess_data)
     return model_server
 
 
@@ -710,25 +678,23 @@ def serve_model(
     """
     # Validation
     organization_name = _get_organization_name(**kwargs)
-    model = read_model(
-        repository_name=repository_name, model_number=model_number, **kwargs
-    )
+    model = read_model(repository_name=repository_name, model_number=model_number, **kwargs)
     if not model.is_servable:
         raise InvalidParamsError("Model is not servable.")
 
     if not remote:
         print("Downloading model artifacts for serving...")
         # Create temporal directory if not exists
-        local_path_root = (
-            f".vessl-serving/{organization_name}/{repository_name}/{model_number}"
-        )
+        local_path_root = f".vessl-serving/{organization_name}/{repository_name}/{model_number}"
         os.makedirs(local_path_root, exist_ok=True)
 
         # Get the list of files to be downloaded. Only the outdated files or the files that are not in the local will be downloaded.
         volume_files = list_model_volume_files(
             repository_name=repository_name, model_number=model_number, recursive=True
         )
-        local_status_filename = ".vessl.localstatus.yaml"  # File that keeps track of the local status of the files
+        local_status_filename = (
+            ".vessl.localstatus.yaml"  # File that keeps track of the local status of the files
+        )
         local_status = {  # Structure of the local status file
             "hash": {},
         }
@@ -740,9 +706,7 @@ def serve_model(
             for volume_file in volume_files:
                 if volume_file.is_dir:
                     continue  # Skip directory
-                if volume_file.hash == local_status.get("hash", {}).get(
-                    volume_file.path, None
-                ):
+                if volume_file.hash == local_status.get("hash", {}).get(volume_file.path, None):
                     continue  # Skip if hash is up to date
                 download_list.append(volume_file)
         else:
