@@ -17,9 +17,7 @@ def list_ssh_keys() -> List[ResponseSSHKeyInfo]:
     return vessl_api.s_sh_key_list_api().ssh_keys
 
 
-def create_ssh_key(
-    key_path: str, key_name: str, ssh_public_key_value: str
-) -> ResponseSSHKeyInfo:
+def create_ssh_key(key_path: str, key_name: str, ssh_public_key_value: str) -> ResponseSSHKeyInfo:
     """Create a SSH public key.
 
     Args:
