@@ -1,4 +1,4 @@
-from typing import Dict, List, Tuple
+from typing import List, Tuple
 
 from openapi_client import ResponseSweepExperimentInfo
 from openapi_client.models import (
@@ -6,8 +6,8 @@ from openapi_client.models import (
     OrmEarlyStoppingSetting,
     OrmEarlyStoppingSpec,
     OrmHyperparameter,
-    OrmParameter,
-    OrmSweepObjective,
+    OrmParameter as SweepParameter,
+    OrmSweepObjective as SweepObjective,
     OrmSweepSearchSpace,
     ResponseSweepInfo,
     ResponseSweepListResponse,
@@ -66,21 +66,21 @@ def list_sweeps(**kwargs) -> List[ResponseSweepListResponse]:
 
 def create_sweep(
     name: str,
-    objective: OrmSweepObjective,
-    max_experiment_count: int,
-    parallel_experiment_count: int,
-    max_failed_experiment_count: int,
     algorithm: str,
-    parameters: List[OrmParameter],
+    parameters: List[SweepParameter],
     cluster_name: str,
-    start_command: str,
-    kernel_resource_spec_name: str = None,
+    command: str,
+    objective: SweepObjective = None,
+    max_experiment_count: int = None,
+    parallel_experiment_count: int = None,
+    max_failed_experiment_count: int = None,
+    resource_spec_name: str = None,
     processor_type: str = None,
     cpu_limit: float = None,
-    memory_limit: float = None,
-    gpu_type: str = None,
+    memory_limit: str = None,
+    gpu_type: str = "Any",
     gpu_limit: int = None,
-    kernel_image_url: str = None,
+    image_url: str = None,
     *,
     early_stopping_name: str = None,
     early_stopping_settings: List[Tuple[str, str]] = None,
@@ -103,36 +103,47 @@ def create_sweep(
 
     Args:
         name(str): Name
-        objective(OrmSweepObjective): A sweep objective including goal, metric,
+        objective(Optional[vessl.SweepObjective]): A sweep objective including goal, metric,
             and type.
-        max_experiment_count(int): The maximum number of experiments to run.
-        parallel_experiment_count(int): The number of experiments to run in
-            parallel.
-        max_failed_experiment_count(int): The maximum number of experiments to
-            allow to fail.
+        max_experiment_count(Optional[int]): The maximum number of experiments to run.
+            Required unless grid search.
+        parallel_experiment_count(Optional[int]): The number of experiments to run in
+            parallel. Default: 1.
+        max_failed_experiment_count(Optional[int]): The maximum number of experiments to
+            allow to fail. Default: 1.
         algorithm(str): Parameter suggestion algorithm. `grid`, `random`, or
             `bayesian`.
-        parameters(List[OrmParameter]): A list of parameters to search.
+        parameters(List[vessl.SweepParameter]): A list of parameters to search.
+            - SweepParameter
+                - name(str): The names of hyperparameters to search.
+                - type(str): `int`, `double`, `categorical`.
+                - range(SweepParameterRange): Search range.
+                    - list(List[str]): A list of values to try.
+                        If `list` is given, `min`, `max` and `step` will be ignored.
+                    - min(str): The minimum value of the search range (inclusive).
+                    - max(str): The maximum value of the search range (inclusive).
+                    - step(Optional[str]): If provided, the values are limited to min + n*step.
         cluster_name(str): Cluster name(must be specified before other options).
-        start_command(str): Start command to execute in experiment container.
-        kernel_resource_spec_name(str):  Resource type to run an experiment (for
+        command(str): Start command to execute in experiment container.
+        resource_spec_name(str):  Resource type to run an experiment (for
             managed cluster only). Defaults to None.
         processor_type(str) cpu or gpu (for custom cluster only). Defaults to
             None.
         cpu_limit(float): Number of vCPUs (for custom cluster only). Defaults to
             None.
-        memory_limit(str): Memory limit in GiB (for custom cluster only).
-            Defaults to None.
-        gpu_type(str): GPU type (for custom cluster only). Defaults to None.
+        memory_limit(str): Memory limit (for custom cluster only).
+            Defaults to None. Example: "100Gi", "500Mi"
+        gpu_type(str): GPU type(name) (for custom cluster only). Defaults to "Any".
+            Example: "RTX-3090-Ti" (Currently the exact name can be found on new experiment page)
         gpu_limit(int): Number of GPU cores (for custom cluster only). Defaults
             to None.
-        kernel_image_url(str): Kernel docker image URL. Defaults to None.
+        image_url(str): Kernel docker image URL. Defaults to None.
         early_stopping_name(str): Early stopping algorithm name. Defaults to
             None.
         early_stopping_settings(List[Tuple[str, str]]): Early stopping algorithm
             settings. Defaults to None.
         message(str): Message. Defaults to None.
-        hyperparameters(List[str]): A list of hyperparameters. Defaults to None.
+        hyperparameters(List[str]): A list of fixed hyperparameters. Defaults to None.
         dataset_mounts(List[str]): A list of dataset mounts. Defaults to None.
         git_ref_mounts(List[str]): A list of git repository mounts. Defaults to
             None.
@@ -169,6 +180,7 @@ def create_sweep(
             )
         ]
 
+        # Custom Cluster
         vessl.create_sweep(
             name="example-sweep-name",
             objective=sweep_objective,
@@ -177,7 +189,27 @@ def create_sweep(
             max_failed_experiment_count=2,
             algorithm="random",
             parameters=parameters,
-            dataset_mounts=[/input:mnist],
+            dataset_mounts=["/input:mnist"],
+            cluster_name="dgx-cluster",
+            processor_type="gpu",
+            gpu_type="NVIDIA-A100-SXM4-80GB",
+            gpu_limit=2,
+            cpu_limit=30,
+            memory_limit="100Gi",
+            kernel_image_url="public.ecr.aws/vessl/kernels:py36.full-cpu",
+            start_command="pip install requirements.txt && python main.py",
+        )
+
+        # VESSL-Managed Cluster
+        vessl.create_sweep(
+            name="example-sweep-name",
+            objective=sweep_objective,
+            max_experiment_count=4,
+            parallel_experiment_count=2,
+            max_failed_experiment_count=2,
+            algorithm="random",
+            parameters=parameters,
+            dataset_mounts=["/input:mnist"],
             cluster_name="aws-apne2-prod1",
             kernel_resource_spec_name="v1.cpu-4.mem-13",
             kernel_image_url="public.ecr.aws/vessl/kernels:py36.full-cpu",
@@ -191,7 +223,7 @@ def create_sweep(
     if cluster.is_savvihub_managed:  # TODO: rename to vessl
         kernel_resource_spec_id = read_kernel_resource_spec(
             cluster.id,
-            kernel_resource_spec_name,
+            resource_spec_name,
         ).id
     else:
         kernel_resource_spec = _configure_custom_kernel_resource_spec(
@@ -242,12 +274,12 @@ def create_sweep(
                     (hyperparameters or []),
                 )
             ],
-            image_url=kernel_image_url,
+            image_url=image_url,
             early_stopping_spec=early_stopping_spec,
             message=message,
             resource_spec=kernel_resource_spec,
             resource_spec_id=kernel_resource_spec_id,
-            start_command=start_command,
+            start_command=command,
             volumes=volume_mount_requests,
         ),
     )
