@@ -1,12 +1,11 @@
 import os
 from typing import Optional, Union
 
-import shortuuid
 import six
-import soundfile as sf
 
 from vessl.util import logger
-from vessl.util.constant import VESSL_AUDIO_PATH, VESSL_MEDIA_PATH
+from vessl.util.common import generate_uuid, get_module
+from vessl.util.constant import VESSL_MEDIA_PATH
 from vessl.util.exception import InvalidParamsError
 
 
@@ -30,11 +29,14 @@ class Audio:
         self._sample_rate = sample_rate
         self._caption = caption
 
-        audio_root = os.path.join(VESSL_MEDIA_PATH, VESSL_AUDIO_PATH)
-        os.makedirs(audio_root, exist_ok=True)
-        self._path = os.path.join(audio_root, Audio.generate_uuid() + ".wav")
+        os.makedirs(VESSL_MEDIA_PATH, exist_ok=True)
+        self._path = os.path.join(VESSL_MEDIA_PATH, generate_uuid() + ".wav")
 
     def _init_audio_from_path(self, path):
+        sf = get_module(
+            "soundfile",
+            required='soundfile package is required. Run "pip install soundfile".',
+        )
         self._audio, self._sample_rate = sf.read(path)
 
     def _init_audio_from_data(self, data):
@@ -51,6 +53,10 @@ class Audio:
             self._init_audio_from_data(data_or_path)
 
     def _save_audio(self):
+        sf = get_module(
+            "soundfile",
+            required='Soundfile package is required. Run "pip install soundfile".',
+        )
         sf.write(self._path, self._audio, self._sample_rate)
 
     def flush(self):
@@ -66,10 +72,3 @@ class Audio:
     @property
     def caption(self):
         return self._caption
-
-    @classmethod
-    def generate_uuid(cls):
-        generated_uuid = shortuuid.ShortUUID(
-            alphabet=list("0123456789abcdefghijklmnopqrstuvwxyz")
-        )
-        return generated_uuid.random(8)
