@@ -32,9 +32,7 @@ def get_module(name, required=None):
 
 
 def generate_uuid():
-    generated_uuid = shortuuid.ShortUUID(
-        alphabet=list("0123456789abcdefghijklmnopqrstuvwxyz")
-    )
+    generated_uuid = shortuuid.ShortUUID(alphabet=list("0123456789abcdefghijklmnopqrstuvwxyz"))
     return generated_uuid.random(8)
 
 
@@ -46,5 +44,5 @@ def is_processor_m1():
 
 def remove_prefix(text, prefix):
     if text.startswith(prefix):
-        return text[len(prefix):]
+        return text[len(prefix) :]
     return text
