@@ -23,11 +23,21 @@ VESSL_LOG_LEVEL = (
 WEB_HOST = os.environ.get("VESSL_WEB_HOST", "https://vessl.ai")
 API_HOST = os.environ.get("VESSL_API_HOST", "https://api.vessl.ai")
 
+DEFAULT_VESSL_SIDECAR_HOST = os.environ.get("VESSL_SIDECAR_HOST", "http://localhost:3000")
+UPDATE_CONTEXT_VARIABLE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/store"
+GET_ARGUMENT_VALUE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/argument"
+GET_CONTEXT_VARIABLE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/context"
+
 LOGIN_TIMEOUT_SECONDS = 160
 ACCESS_TOKEN_ENV_VAR = "VESSL_ACCESS_TOKEN"
 DEFAULT_ORGANIZATION_ENV_VAR = "VESSL_DEFAULT_ORGANIZATION"
+DEFAULT_PROJECT_ENV_VAR = "VESSL_DEFAULT_PROJECT"
 CREDENTIALS_FILE_ENV_VAR = "VESSL_CREDENTIALS_FILE"
 
+CLUSTER_KUBECONFIG_ENV_VAR = "VESSL_CLUSTER_KUBECONFIG"
+CLUSTER_MODE_SINGLE = "single"
+CLUSTER_MODE_MULTI_NODE = "multi"
+
 PROJECT_TYPE_VERSION_CONTROL = "version-control"
 PROJECT_TYPES = [PROJECT_TYPE_VERSION_CONTROL]
 
@@ -101,7 +111,9 @@ VESSL_PLOTS_FILETYPE_IMAGES = "images"
 VESSL_PLOTS_FILETYPE_AUDIO = "audio"
 
 WORKSPACE_BACKUP_MAX_SIZE = 15 * 1024 * 1024 * 1024
-WORKSPACE_BACKUP_MAX_SIZE_FORMATTED = humanfriendly.format_size(WORKSPACE_BACKUP_MAX_SIZE, binary=True)
+WORKSPACE_BACKUP_MAX_SIZE_FORMATTED = humanfriendly.format_size(
+    WORKSPACE_BACKUP_MAX_SIZE, binary=True
+)
 
 TEMP_DIR = tempfile.gettempdir()
 
