@@ -36,9 +36,7 @@ class UploadableFileObject:
     def upload_hooks(self, *, callback=None):
         def fn(resp, **kwargs):
             if resp.status_code != 200:
-                logger.warning(
-                    f"Upload for {resp.request.url} failed. Detail: {resp.data}"
-                )
+                logger.warning(f"Upload for {resp.request.url} failed. Detail: {resp.data}")
 
         return {
             "response": fn,
