@@ -45,13 +45,7 @@ class Image:
         )
         if Image.get_type_name(data).startswith("torch."):
             self._image = pil_image.fromarray(
-                data.mul(255)
-                .clamp(0, 255)
-                .byte()
-                .permute(1, 2, 0)
-                .squeeze()
-                .cpu()
-                .numpy()
+                data.mul(255).clamp(0, 255).byte().permute(1, 2, 0).squeeze().cpu().numpy()
             )
         elif isinstance(data, pil_image.Image):
             self._image = data
