@@ -1,14 +1,14 @@
 import os
 from typing import Dict, List, Optional
 
-from openapi_client import ProtoVolumeMountRequestSourceModelVolume
+from openapi_client import OrmVolumeMountRequestSourceModelVolume
 from openapi_client.models import (
-    ProtoVolumeMountRequest,
-    ProtoVolumeMountRequests,
-    ProtoVolumeMountRequestSourceArchiveFile,
-    ProtoVolumeMountRequestSourceCode,
-    ProtoVolumeMountRequestSourceDataset,
-    ProtoVolumeMountRequestSourceDatasetVersion,
+    OrmVolumeMountRequest,
+    OrmVolumeMountRequests,
+    OrmVolumeMountRequestSourceArchiveFile,
+    OrmVolumeMountRequestSourceCode,
+    OrmVolumeMountRequestSourceDataset,
+    OrmVolumeMountRequestSourceDatasetVersion,
     StorageFile,
     VolumeFileCopyAPIInput,
     VolumeFileCreateAPIInput,
@@ -251,9 +251,7 @@ def _copy_volume_file_local_to_remote(
         return [uploaded_file]
 
     if dest_file and not dest_file.is_dir:
-        raise InvalidVolumeFileError(
-            f"Destination path is not a directory: {dest_path}."
-        )
+        raise InvalidVolumeFileError(f"Destination path is not a directory: {dest_path}.")
 
     if dest_file and dest_file.is_dir:
         dest_path = os.path.join(dest_path, os.path.basename(source_path))
@@ -289,9 +287,7 @@ def _copy_volume_file_remote_to_local(
         if os.path.isfile(dest_path):
             # Case where `source_path` is a directory and `dest_path` is an
             # existing filename
-            raise InvalidVolumeFileError(
-                f"Destination path is not a directory: {dest_path}."
-            )
+            raise InvalidVolumeFileError(f"Destination path is not a directory: {dest_path}.")
 
         files = list_volume_files(
             volume_id=source_volume_id,
@@ -339,7 +335,7 @@ def _copy_volume_file_remote_to_remote(
 
 
 def _print_volume_mount_requests_tree(
-    requests: ProtoVolumeMountRequests,
+    requests: OrmVolumeMountRequests,
 ):
     print("Mount Info:")
     for request in requests.requests:
@@ -375,42 +371,32 @@ def _configure_volume_mount_requests(
     local_files: Optional[List[str]] = None,
     upload_local_git_diff: bool = False,
     **kwargs,
-) -> ProtoVolumeMountRequests:
+) -> OrmVolumeMountRequests:
     requests = [
         _configure_volume_mount_request_empty_dir(),
         _configure_volume_mount_request_output(output_dir),
     ]
 
     if local_files:
-        requests.extend(
-            _configure_volume_mount_request_local_files(local_files, **kwargs)
-        )
+        requests.extend(_configure_volume_mount_request_local_files(local_files, **kwargs))
 
     if not git_ref_mounts and git_diff_mount is None and archive_file_mount is None:
         # No information for code mount is given - user is creating new experiment from CLI.
         # Generate VolumeMountRequest from projectRepository and local working directory
-        requests.extend(
-            _configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs)
-        )
+        requests.extend(_configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs))
     else:
         # Explicit information for code mount is given - user is reproducing experiment from CLI.
         if git_ref_mounts:
             requests.extend(
-                _configure_volume_mount_request_codes(
-                    git_ref_mounts, git_diff_mount, **kwargs
-                )
+                _configure_volume_mount_request_codes(git_ref_mounts, git_diff_mount, **kwargs)
             )
         if archive_file_mount is not None:
             requests.append(
-                _configure_volume_mount_request_archive_file(
-                    archive_file_mount, **kwargs
-                )
+                _configure_volume_mount_request_archive_file(archive_file_mount, **kwargs)
             )
 
     if dataset_mounts is not None:
-        requests.extend(
-            _configure_volume_mount_request_datasets(dataset_mounts, **kwargs)
-        )
+        requests.extend(_configure_volume_mount_request_datasets(dataset_mounts, **kwargs))
 
     if model_mounts is not None:
         requests += [
@@ -418,7 +404,7 @@ def _configure_volume_mount_requests(
             for model_mount in model_mounts
         ]
 
-    requests = ProtoVolumeMountRequests(
+    requests = OrmVolumeMountRequests(
         root_volume_size=root_volume_size,
         working_dir=working_dir,
         requests=requests,
@@ -429,20 +415,20 @@ def _configure_volume_mount_requests(
 
 def _configure_volume_mount_request_datasets(
     dataset_mounts: List[str], should_add_project_datasets=True, **kwargs
-) -> List[ProtoVolumeMountRequest]:
+) -> List[OrmVolumeMountRequest]:
     from vessl.dataset import read_dataset, read_dataset_version
 
-    dataset_mount_map: Dict[int, ProtoVolumeMountRequest] = {}
+    dataset_mount_map: Dict[int, OrmVolumeMountRequest] = {}
     if should_add_project_datasets:
         project = _get_project(**kwargs)
         for project_dataset in project.project_datasets:
             mount_path = project_dataset.mount_path
             dataset = project_dataset.dataset
 
-            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+            dataset_mount_map[dataset.id] = OrmVolumeMountRequest(
                 source_type=SOURCE_TYPE_DATASET,
                 mount_path=mount_path,
-                dataset=ProtoVolumeMountRequestSourceDataset(
+                dataset=OrmVolumeMountRequestSourceDataset(
                     dataset_id=dataset.id,
                     dataset_name=dataset.name,
                 ),
@@ -467,10 +453,10 @@ def _configure_volume_mount_request_datasets(
         dataset = read_dataset(dataset_name, organization_name=organization_name)
 
         if not dataset.is_version_enabled:
-            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+            dataset_mount_map[dataset.id] = OrmVolumeMountRequest(
                 source_type=SOURCE_TYPE_DATASET,
                 mount_path=mount_path,
-                dataset=ProtoVolumeMountRequestSourceDataset(
+                dataset=OrmVolumeMountRequestSourceDataset(
                     dataset_id=dataset.id,
                     dataset_name=dataset_name,
                 ),
@@ -481,10 +467,10 @@ def _configure_volume_mount_request_datasets(
                 dataset.id, dataset_version_hash
             ).version_hash  # Get full version hash from truncated one given by input
 
-            dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
+            dataset_mount_map[dataset.id] = OrmVolumeMountRequest(
                 source_type=SOURCE_TYPE_DATASET_VERSION,
                 mount_path=mount_path,
-                dataset_version=ProtoVolumeMountRequestSourceDatasetVersion(
+                dataset_version=OrmVolumeMountRequestSourceDatasetVersion(
                     dataset_id=dataset.id,
                     dataset_name=dataset_name,
                     dataset_version_hash=dataset_version_hash,
@@ -494,9 +480,7 @@ def _configure_volume_mount_request_datasets(
     return list(dataset_mount_map.values())
 
 
-def _configure_volume_mount_request_model(
-    model_mount: str, **kwargs
-) -> ProtoVolumeMountRequest:
+def _configure_volume_mount_request_model(model_mount: str, **kwargs) -> OrmVolumeMountRequest:
     from vessl.model import read_model
 
     mount_path, model_path = model_mount.split(":", 1)
@@ -504,14 +488,12 @@ def _configure_volume_mount_request_model(
 
     mount_path = os.path.join(mount_path, "")  # Ensure path ends in /
 
-    model = read_model(
-        repository_name=model_repository_name, model_number=model_number, **kwargs
-    )
+    model = read_model(repository_name=model_repository_name, model_number=model_number, **kwargs)
 
-    return ProtoVolumeMountRequest(
+    return OrmVolumeMountRequest(
         source_type=SOURCE_TYPE_MODEL_VOLUME,
         mount_path=mount_path,
-        model_volume=ProtoVolumeMountRequestSourceModelVolume(
+        model_volume=OrmVolumeMountRequestSourceModelVolume(
             sub_path="/",
             model_repository_name=model.model_repository.name,
             model_number=model.number,
@@ -521,10 +503,10 @@ def _configure_volume_mount_request_model(
 
 def _configure_volume_mount_request_local_files(
     local_files: List[str], **kwargs
-) -> List[ProtoVolumeMountRequest]:
+) -> List[OrmVolumeMountRequest]:
     project = _get_project(**kwargs)
 
-    volume_mount_requests: List[ProtoVolumeMountRequest] = []
+    volume_mount_requests: List[OrmVolumeMountRequest] = []
     for local_file in local_files:
         if ":" in local_file:
             local_path, remote_path = local_file.split(":")
@@ -561,7 +543,7 @@ def _configure_volume_mount_request_local_files(
 
 def _configure_volume_mount_request_local_git(
     upload_local_git_diff, **kwargs
-) -> List[ProtoVolumeMountRequest]:
+) -> List[OrmVolumeMountRequest]:
     project = _get_project(**kwargs)
 
     local_git_owner, local_git_repo = None, None
@@ -570,7 +552,7 @@ def _configure_volume_mount_request_local_git(
     except GitError:
         pass
 
-    volume_mount_requests: List[ProtoVolumeMountRequest] = []
+    volume_mount_requests: List[OrmVolumeMountRequest] = []
     used_mount_paths = set()
     for repo in project.project_repositories:
         mount_path = f"{EXPERIMENT_WORKING_DIR}{repo.git_repo}"
@@ -591,9 +573,7 @@ def _configure_volume_mount_request_local_git(
         volume_mount_requests.append(
             _configure_volume_mount_request_code(
                 git_ref_mount=f"{mount_path}:{git_mount_info}",
-                git_diff_mount=None
-                if git_diff_path is None
-                else f"{mount_path}:{git_diff_path}",
+                git_diff_mount=None if git_diff_path is None else f"{mount_path}:{git_diff_path}",
             )
         )
 
@@ -602,7 +582,7 @@ def _configure_volume_mount_request_local_git(
 
 def _configure_volume_mount_request_codes(
     git_ref_mounts: List[str], git_diff_mount: str, **kwargs
-) -> List[ProtoVolumeMountRequest]:
+) -> List[OrmVolumeMountRequest]:
     return [
         _configure_volume_mount_request_code(git_ref_mount, git_diff_mount, **kwargs)
         for git_ref_mount in git_ref_mounts
@@ -611,13 +591,13 @@ def _configure_volume_mount_request_codes(
 
 def _configure_volume_mount_request_code(
     git_ref_mount: str, git_diff_mount: str, **kwargs
-) -> ProtoVolumeMountRequest:
-    # Generate ProtoVolumeMountRequestSourceCode from git_ref_mount
+) -> OrmVolumeMountRequest:
+    # Generate OrmVolumeMountRequestSourceCode from git_ref_mount
     # ref_mount_info = <provider>/<owner>/<repo>/<commit>
     ref_mount_path, ref_mount_info = git_ref_mount.split(":", 1)
     code_info = ref_mount_info.split("/", 3)
 
-    vmr_source_code = ProtoVolumeMountRequestSourceCode(
+    vmr_source_code = OrmVolumeMountRequestSourceCode(
         git_provider=code_info[0],
         git_owner=code_info[1],
         git_repo=code_info[2],
@@ -630,7 +610,7 @@ def _configure_volume_mount_request_code(
         if ref_mount_path == diff_mount_path:
             vmr_source_code.git_diff_file = diff_mount_file
 
-    return ProtoVolumeMountRequest(
+    return OrmVolumeMountRequest(
         source_type=SOURCE_TYPE_CODE,
         mount_path=ref_mount_path,
         code=vmr_source_code,
@@ -639,27 +619,27 @@ def _configure_volume_mount_request_code(
 
 def _configure_volume_mount_request_archive_file(
     archive_file_mount: str,
-) -> ProtoVolumeMountRequest:
+) -> OrmVolumeMountRequest:
     mount_path, archive_file_path = archive_file_mount.split(":", 1)
 
-    return ProtoVolumeMountRequest(
+    return OrmVolumeMountRequest(
         source_type=SOURCE_TYPE_ARCHIVE_FILE,
         mount_path=mount_path,
-        archive_file=ProtoVolumeMountRequestSourceArchiveFile(
+        archive_file=OrmVolumeMountRequestSourceArchiveFile(
             archive_file=archive_file_path,
         ),
     )
 
 
-def _configure_volume_mount_request_empty_dir() -> ProtoVolumeMountRequest:
-    return ProtoVolumeMountRequest(
+def _configure_volume_mount_request_empty_dir() -> OrmVolumeMountRequest:
+    return OrmVolumeMountRequest(
         source_type=SOURCE_TYPE_EMPTY_DIR,
         mount_path=MOUNT_PATH_EMPTY_DIR,
     )
 
 
-def _configure_volume_mount_request_output(output_dir: str) -> ProtoVolumeMountRequest:
-    return ProtoVolumeMountRequest(
+def _configure_volume_mount_request_output(output_dir: str) -> OrmVolumeMountRequest:
+    return OrmVolumeMountRequest(
         source_type=SOURCE_TYPE_OUTPUT,
         mount_path=output_dir,
     )
